${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.subtitle, notes) }

${ _("Equipment") }: | ${ report.workorder.equipment }
${ _("Client") }: | ${ report.workorder.client.person.name } | ${ _("Estimated cost") }: | ${ format_price(report.workorder.estimated_cost) if \ report.workorder.estimated_cost else '' }
${ _("Estimated start") }: | ${ format_date(report.workorder.estimated_start) } | ${ _("Estimated finish") }: | ${ format_date(report.workorder.estimated_finish) }

${ _("Quote") }:

    ${ report.workorder.defect_detected }

% if report.workorder.quote_responsible:

${ _("Responsible signature") }
${ report.workorder.quote_responsible.get_description() }
% endif